package de.intevation.flys.artifacts.model.fixings;

import de.intevation.flys.artifacts.model.Parameters;

import de.intevation.flys.utils.KMIndex;

import java.io.Serializable;

public class FixResult
implements   Serializable
{
    protected Parameters                 parameters;
    protected KMIndex<QWD []>            referenced;
    protected KMIndex<QW []>             outliers;
    protected KMIndex<AnalysisPeriod []> analysisPeriods;

    public FixResult() {
    }

    public FixResult(
        Parameters                 parameters,
        KMIndex<QWD []>            referenced,
        KMIndex<QW []>             outliers,
        KMIndex<AnalysisPeriod []> analysisPeriods
    ) {
        this.parameters      = parameters;
        this.referenced      = referenced;
        this.outliers        = outliers;
        this.analysisPeriods = analysisPeriods;
    }

    public int getUsedSectorsInAnalysisPeriods() {
        int result = 0;
        for (KMIndex.Entry<AnalysisPeriod []> entry: analysisPeriods) {
            for (AnalysisPeriod period: entry.getValue()) {
                for (int i = 0; i < 4; ++i) {
                    result |= period.getQSectorAverage(i) != null
                        ? (1 << i)
                        : 0;
                }
                // XXX: Stop early on result == ~(~0 << 4)) ?
            }
        }
        return result;
    }

    public Parameters getParameters() {
        return parameters;
    }

    public void setParameters(Parameters parameters) {
        this.parameters = parameters;
    }

    public KMIndex<AnalysisPeriod []> getAnalysisPeriods() {
        return analysisPeriods;
    }

    public void setAnalysisPeriods(KMIndex<AnalysisPeriod []> analysisPeriods) {
        this.analysisPeriods = analysisPeriods;
    }

    public KMIndex<QWD []> getReferenced() {
        return referenced;
    }

    public void setReferenced(KMIndex<QWD []> referenced) {
        this.referenced = referenced;
    }

    public KMIndex<QW []> getOutliers() {
        return outliers;
    }

    public void setOutliers(KMIndex<QW []> outliers) {
        this.outliers = outliers;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
